@@ -1,14 +1,3 @@
-/*!
-`cargo-script` is a Cargo subcommand designed to let people quickly and easily run Rust "scripts" which can make use of Cargo's package ecosystem.
-
-Or, to put it in other words, it lets you write useful, but small, Rust programs without having to create a new directory and faff about with `Cargo.toml`.
-
-As such, `cargo-script` does two major things:
-
-1. Given a script, it extracts the embedded Cargo manifest and merges it with some sensible defaults.  This manifest, along with the source code, is written to a fresh Cargo package on-disk.
-
-2. It caches the generated and compiled packages, regenerating them only if the script or its metadata have changed.
-*/
 #![forbid(unsafe_code)]
 extern crate env_logger;
 #[macro_use]
@@ -533,12 +522,12 @@ fn try_main() -> Result<i32> {
         }
         let add_env = hint(move |cmd| {
             cmd.env(
-                "CARGO_SCRIPT_SCRIPT_PATH",
+                "RUST_SCRIPT_PATH",
                 input.path().unwrap_or_else(|| Path::new("")),
             );
-            cmd.env("CARGO_SCRIPT_SAFE_NAME", input.safe_name());
-            cmd.env("CARGO_SCRIPT_PKG_NAME", input.package_name());
-            cmd.env("CARGO_SCRIPT_BASE_PATH", input.base_path());
+            cmd.env("RUST_SCRIPT_SAFE_NAME", input.safe_name());
+            cmd.env("RUST_SCRIPT_PKG_NAME", input.package_name());
+            cmd.env("RUST_SCRIPT_BASE_PATH", input.base_path());
             cmd
         });
 
@@ -720,6 +709,7 @@ fn gen_pkg_and_compile(input: &Input, action: &InputAction) -> Result<()> {
             "build",
             &*mani_path.to_string_lossy(),
             action.use_bincache,
+            action.use_nightly,
             &meta,
         )?;
 
@@ -746,6 +736,7 @@ fn gen_pkg_and_compile(input: &Input, action: &InputAction) -> Result<()> {
             pkg_path,
             &*mani_path.to_string_lossy(),
             action.use_bincache,
+            action.use_nightly,
             &meta,
         )?;
 
@@ -805,6 +796,8 @@ struct InputAction {
     /// Use shared binary cache?
     use_bincache: bool,
 
+    use_nightly: bool,
+
     /// The package metadata structure for the current invocation.
     metadata: PackageMetadata,
 
@@ -831,6 +824,7 @@ impl InputAction {
             cmd,
             &*self.manifest_path().to_string_lossy(),
             self.use_bincache,
+            self.use_nightly,
             &self.metadata,
         )
     }
@@ -952,6 +946,7 @@ fn decide_action_for(
         pkg_path,
         using_cache,
         use_bincache: args.use_bincache.unwrap_or(using_cache),
+        use_nightly: matches!(args.build_kind, BuildKind::Bench),
         metadata: input_meta,
         old_metadata: None,
         manifest: mani_str,
@@ -1370,9 +1365,13 @@ fn cargo(
     cmd_name: &str,
     manifest: &str,
     use_bincache: bool,
+    nightly: bool,
     meta: &PackageMetadata,
 ) -> Result<Command> {
     let mut cmd = Command::new("cargo");
+    if nightly {
+        cmd.arg("+nightly");
+    }
     cmd.arg(cmd_name).arg("--manifest-path").arg(manifest);
 
     if platform::force_cargo_color() {
@@ -1410,6 +1409,7 @@ fn cargo_target<P>(
     pkg_path: P,
     manifest: &str,
     use_bincache: bool,
+    use_nightly: bool,
     meta: &PackageMetadata,
 ) -> Result<PathBuf>
 where
@@ -1422,7 +1422,7 @@ where
         use_bincache
     );
 
-    let exe_path = cargo_target_by_message(input, manifest, use_bincache, meta)?;
+    let exe_path = cargo_target_by_message(input, manifest, use_bincache, use_nightly, meta)?;
 
     trace!(".. exe_path: {:?}", exe_path);
 
@@ -1446,6 +1446,7 @@ fn cargo_target_by_message(
     input: &Input,
     manifest: &str,
     use_bincache: bool,
+    use_nightly: bool,
     meta: &PackageMetadata,
 ) -> Result<PathBuf> {
     use std::io::{BufRead, BufReader};
@@ -1456,7 +1457,7 @@ fn cargo_target_by_message(
         use_bincache
     );
 
-    let mut cmd = cargo("build", manifest, use_bincache, meta)?;
+    let mut cmd = cargo("build", manifest, use_bincache, use_nightly, meta)?;
     cmd.arg("--message-format=json");
     cmd.stdout(process::Stdio::piped());
     cmd.stderr(process::Stdio::null());
